==> RWebServices_1.6.0.tar.gz: RWebServices/inst/rservices/src/org/bioconductor/packages/rservices/RJDataFrame.java <==
/**
 * RJDataFrame.java
 * 
 * This java class corresponds to R data frame 
 */
package org.bioconductor.packages.rservices;

import java.util.Arrays;

public class RJDataFrame implements java.io.Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	protected Object[] data = new Object[0];

	protected String[] rowNames = new String[0];

	public RJDataFrame() {
	}

	public RJDataFrame(Object[] data, String[] rowNames) {
		this.data = data;
		this.rowNames = rowNames;
	}

	/**
	 * Sets the data for this RJDataFrame.
	 * 
	 * @param data
	 */
	public void setData(Object[] data) {
		this.data = data;
	}

	/**
	 * Gets the data for this RJDataFrame.
	 * 
	 * @return data
	 */
	public Object[] getData() {
		return data;
	}

	/**
	 * Sets the rowNames for this RJDataFrame.
	 * 
	 * @param rowNames
	 */
	public void setRowNames(String[] rowNames) {
		this.rowNames = rowNames;
	}

	/**
	 * Sets the rowNames for this RJDataFrame.
	 * 
	 * @param rowNames
	 */
	public void setRowNames(String rowNames) {
		this.rowNames = new String[] { rowNames };
	}

	/**
	 * Gets the rowNames value for this RJDataFrame.
	 * 
	 * @return rowNames
	 */
	public String[] getRowNames() {
		return rowNames;
	}

	@Override
	public boolean equals(Object inputObject) {
		boolean res = getClass().equals(inputObject.getClass());
		if (res) {
			RJDataFrame obj = (RJDataFrame) inputObject;
			Object[] objData = obj.getData();
			String[] objRowNames = obj.getRowNames();
			res = res && Arrays.deepEquals(data, objData);
			res = res && Arrays.equals(rowNames, objRowNames);
		}
		return res;
	}

	@Override
	public String toString() {
		StringBuffer res = new StringBuffer("RDdataFrame {\ndata=");
		res.append(Arrays.deepToString(data));
		res.append("\nrownames=" + Arrays.toString(rowNames));
		res.append("\n}");
		return res.toString();
	}
}

==> RWebServices_1.8.0.tar.gz: RWebServices/inst/rservices/src/org/bioconductor/packages/rservices/RJDataFrame.java <==
/**
 * RJDataFrame.java
 * 
 * This java class corresponds to R data frame 
 */
package org.bioconductor.packages.rservices;

import java.util.Arrays;

public class RJDataFrame implements java.io.Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	protected Object[] data = new Object[0];

	protected String[] rowNames = new String[0];
	
	protected String[] colNames = new String[0];

	public RJDataFrame() {
	}

	public RJDataFrame(Object[] data, String[] rowNames, String[] colNames) {
		this.data = data;
		this.rowNames = rowNames;
		this.colNames = colNames;
	}

	/**
	 * Sets the data for this RJDataFrame.
	 * 
	 * @param data
	 */
	public void setData(Object[] data) {
		this.data = data;
	}

	/**
	 * Gets the data for this RJDataFrame.
	 * 
	 * @return data
	 */
	public Object[] getData() {
		return data;
	}

	/**
	 * Sets the rowNames for this RJDataFrame.
	 * 
	 * @param rowNames
	 */
	public void setRowNames(String[] rowNames) {
		this.rowNames = rowNames;
	}

	/**
	 * Sets the rowNames for this RJDataFrame.
	 * 
	 * @param rowNames
	 */
	public void setRowNames(String rowNames) {
		this.rowNames = new String[] { rowNames };
	}

	/**
	 * Gets the colNames value for this RJDataFrame.
	 * 
	 * @return colNames
	 */
	public String[] getColNames() {
		return colNames;
	}

	/**
	 * Sets the colNames for this RJDataFrame.
	 * 
	 * @param colNames
	 */
	public void setColNames(String[] colNames) {
		this.colNames = colNames;
	}

	/**
	 * Sets the colNames for this RJDataFrame.
	 * 
	 * @param colNames
	 */
	public void setColNames(String colNames) {
		this.colNames = new String[] { colNames };
	}

	/**
	 * Gets the rowNames value for this RJDataFrame.
	 * 
	 * @return rowNames
	 */
	public String[] getRowNames() {
		return rowNames;
	}

	@Override
	public boolean equals(Object inputObject) {
		boolean res = getClass().equals(inputObject.getClass());
		if (res) {
			RJDataFrame obj = (RJDataFrame) inputObject;
			Object[] objData = obj.getData();
			String[] objRowNames = obj.getRowNames();
			String[] objColNames = obj.getColNames();
			res = res && Arrays.deepEquals(data, objData);
			res = res && Arrays.equals(rowNames, objRowNames);
			res = res && Arrays.equals(colNames, objColNames);
		}
		return res;
	}

	@Override
	public String toString() {
		StringBuffer res = new StringBuffer("RDdataFrame {\ndata=");
		res.append(Arrays.deepToString(data));
		res.append("\nrownames=" + Arrays.toString(rowNames));
		res.append("\ncolnames=" + Arrays.toString(colNames));
		res.append("\n}");
		return res.toString();
	}
}
